'******************************************************************************
'
'  Title:  VRKCustomerInventory.vbs
'
'  Description:  A script to retrieve some items for inventory purposes.
'
'  Dependencies:  Execute using cscript.
'
'  Notes: You must create a DSN for the BDD 2007 database in the Data Sources
'         (ODBC) control panel. If the name of the DSN is not "woodgrove", then
'         update the subAddBDDRecord() function with the new name.
'
'         This script is just an example of how you can inventory a small network
'         to prepopulate the BDD 2007 database with computer settings. Use this
'         script as a starting point for your own inventory script.
'
'  History:
'     09-Nov-2006 Created.
'
'******************************************************************************

'******************************************************************************
'
' Variable Declarations
'
'******************************************************************************

Option Explicit                       ' Insures all variables are defined

' Variables

Dim objArguments
Dim objShell
Dim objShellExec
Dim objRegistry                        ' Registry
Dim objWMI                             ' WMI
Dim objFSO                             ' Filesystem object

Dim strPC2Query                        ' IP address of PC to collect inventory
Dim strWinMgmt                         ' WMI
Dim strRegistry
Dim strComputerName                    ' PC Name
Dim strDomainName                      ' Domain that PC belongs
Dim strSerialNumber                    ' PC Serial Number
Dim strAssetTag                        ' PC Asset Tag
Dim strMfg                             ' PC Manufacturer
Dim strModel                           ' PC Model
Dim strUser                            ' Registered User
Dim strOrganization                    ' Registered Organization
Dim strIEHomePage                      ' Internet Explorer machine home page
Dim strMACAddr                         ' NIC MAC address
Dim strSubnetPrefix
Dim intSubnetStart
Dim intSubnetEnd
Dim strPingResults

Dim intCounter

' Constants
Const HKCU = &H80000001                ' HKEY_CURRENT_USER
Const HKLM = &H80000002                ' HKEY_LOCAL_MACHINE

On Error Resume Next

set objArguments = WScript.Arguments

Set objFSO = CreateObject("Scripting.FileSystemObject")

Set objShell = CreateObject("WScript.Shell")

If (objArguments.Count <> 1) Then
    WScript.Echo "Usage: VRKCustomerInventory.vbs <subnet>"
    WScript.Echo "  <subnet> = subnet to inventory where format is x.y.z."
    WScript.Echo "             Example:  192.168.0."
    WScript.Quit
Else
  strSubnetPrefix = WScript.Arguments(0)
End If

intSubnetStart = 1
intSubnetEnd = 254

For intCounter = intSubnetStart To intSubnetEnd
    strPC2Query = strSubnetPrefix & intCounter
    WScript.Echo("Attmpting to inventory " & strPC2Query & "...")
    set objShellExec = objShell.Exec("ping -n 2 -w 1000 " & strPC2Query)
    strPingResults = LCase(objShellExec.StdOut.ReadAll)
    If Instr(strPingResults, "reply from") Then
        strWinMgmt = "winmgmts:\\" & strPC2Query

        strRegistry = "winmgmts:{impersonationLevel=impersonate}!\\" & _
          strPC2Query & "\root\default:StdRegProv"

        Set objWMI = GetObject(strWinMgmt)

        If Err = 0 Then

            Set objRegistry = GetObject(strRegistry)

            subGetPCName()
            subGetAssetInfo()
            subGetUserInfo()
            subGetMfgInfo()
            subGetNetInfo()
            subPrint2Screen()
            subAddBDDRecord()
        Else
           WScript.Echo(strPC2Query & " - " & Err.Description)
        End If

        Err.Clear

    End If

    Set objWMI = Nothing          ' Clean up

Next

' End of Main
WScript.Quit


'******************************************************************************
'
' Retrieve Asset information
'
'******************************************************************************

Sub subGetAssetInfo()

    Dim colAsset                        ' Collection of BIOS objects
    Dim objAsset                        ' BIOS object

    If IsNull(objWMI) Then
        Exit Sub
    End If

    Set colAsset = objWMI.ExecQuery _
      ("Select SerialNumber, SMBIOSAssetTag From Win32_SystemEnclosure")
    For Each objAsset in colAsset
        strSerialNumber = objAsset.SerialNumber
        strAssetTag = objAsset.SMBIOSAssetTag
    Next

    If IsNull(strSerialNumber) or strSerialNumber = ""  Then
  strSerialNumber = "Unknown"
    End If

    If IsNull(strAssetTag) or strAssetTag = "" Then
  strAssetTag = "Unknown"
    End If

End Sub

'******************************************************************************
'
' Retrieve PC manufacturer information
'
'******************************************************************************

Sub subGetMfgInfo()

    Dim colMfg          ' Collection of manufacturer objects
    Dim objMFG          ' Manufacturer object

    If IsNull(objWMI) Then
  Exit Sub
    End If

    Set colMfg = objWMI.ExecQuery("Select Manufacturer, Model From Win32_ComputerSystem")
    For Each objMFG in colMfg
  strMfg = objMFG.Manufacturer
  ' Trims the trailing spaces on the right-hand side of oMFG.Model
  strModel = RTrim(objMFG.Model)
    Next

End Sub

'******************************************************************************
'
' Retrieve PC name
'
'******************************************************************************

Sub subGetPCName()

    Dim colCompSys                     ' Collection of Computer System objects
    Dim objCompSys                     ' Computer System object

    If IsNull(objWMI) Then
  Exit Sub
    End If

    Set colCompSys = objWMI.ExecQuery("Select Name, Domain From Win32_ComputerSystem")
    For Each objCompSys in colCompSys
        strComputerName = objCompSys.Name
        If IsNull(objCompSys.Domain) Then
            strDomainName = objCompSys.Workgroup
        Else
            strDomainName = objCompSys.Domain
        End If
    Next

End Sub

'******************************************************************************
'
' Retrieve network information
'
'******************************************************************************

Sub subGetNetInfo()

    Dim colNet          ' Collection of network objects
    Dim objNetwork        ' Network object

    If IsNull(objWMI) Then
  Exit Sub
    End If


    Set colNet = objWMI.ExecQuery("Select MacAddress, NetConnectionID From Win32_NetworkAdapter Where NetConnectionID ='Local Area Connection'")
    For Each objNetwork in colNet
        strMACAddr = objNetwork.MacAddress
    Next

End Sub

'******************************************************************************
'
'  Retrieve User information
'
'******************************************************************************

Sub subGetUserInfo()

    Dim colOS         ' Collection of OS objects
    Dim objOS         ' OS obj
    Dim intOSLanguage       ' Flag for OS language
    Dim dtmInstallDate        ' Date string
    Dim intS2K3                                 ' Check for Windows Server 2003
    Dim strOSOther                              ' Other description (contains R2 for Windows Server 2003)

    If IsNull(objWMI) Then
  Exit Sub
    End If

    Set colOS = objWMI.ExecQuery("Select Organization, RegisteredUser From Win32_OperatingSystem")
    For Each objOS in colOS
  strUser = objOS.RegisteredUser
  strOrganization = objOS.Organization
    Next

End Sub

'******************************************************************************
'
'  Print to screen
'
'******************************************************************************

Sub subPrint2Screen()

    WScript.Echo(vbCrLf & "Vista Resource Kit - Customer Inventory:")
    WScript.Echo("  MAC Address" & vbTab & vbTab & vbTab & strMACAddr)
    WScript.Echo("  Computer Name" & vbTab & vbTab & vbTab & strComputerName)
    WScript.Echo("  Serial Number" & vbTab & vbTab & vbTab & strSerialNumber)
    WScript.Echo("  Asset Tag" & vbTab & vbTab & vbTab & strAssetTag)
    WScript.Echo("  Make" & vbTab & vbTab  & vbTab& vbTab & strMfg)
    WScript.Echo("  Model" & vbTab & vbTab & vbTab & vbTab & strModel)
    WScript.Echo("  Registered User" & vbTab & vbTab & strUser)
    WScript.Echo("  Registered Organization" & vbTab & strOrganization)
    WScript.Echo("  Domain/Workgroup" & vbTab & vbTab & strDomainName)
    WScript.Echo()

End Sub

'******************************************************************************
'
'  Add record to BDD database
'
'******************************************************************************

Sub subAddBDDRecord()

    Const adOpenStatic = 3
    Const adLockOptimistic = 3
    Const adUseClient = 3

    Dim objConnection
    Dim objRecordSet
    Dim intIndex

    Set objConnection = CreateObject("ADODB.Connection")
    Set objRecordset = CreateObject("ADODB.Recordset")

    objConnection.Open "DSN=woodgrove;"
    objRecordset.CursorLocation = adUseClient
    objRecordset.Open "SELECT * FROM ComputerIdentity" , objConnection, adOpenStatic, adLockOptimistic

    objRecordset.AddNew
    objRecordset("MACAddress") = strMACAddr
    objRecordset("AssetTag") = strAssetTag
    objRecordset("SerialNumber") = strSerialNumber
    objRecordset.Update

    intIndex = objRecordset( "ID" )
    wscript.echo intIndex
    objRecordSet.MoveNext
    objRecordset.Close

    objRecordset.Open "SELECT * FROM Settings" , objConnection, adOpenStatic, adLockOptimistic

    objRecordset.AddNew
    objRecordset("Type") = "C"
    objRecordset("ID") = intIndex
    objRecordset("ComputerName") = strComputerName
    objRecordset("JoinDomain") = strDomainName
    objRecordset("FullName") = strUser
    objRecordset("OrgName") = strOrganization
    objRecordset.Update
    objRecordSet.MoveNext
    objRecordset.Close

End Sub

'' SIG '' Begin signature block
'' SIG '' MIIlaAYJKoZIhvcNAQcCoIIlWTCCJVUCAQExCzAJBgUr
'' SIG '' DgMCGgUAMGcGCisGAQQBgjcCAQSgWTBXMDIGCisGAQQB
'' SIG '' gjcCAR4wJAIBAQQQTvApFpkntU2P5azhDxfrqwIBAAIB
'' SIG '' AAIBAAIBAAIBADAhMAkGBSsOAwIaBQAEFCsf0Hudyh5G
'' SIG '' OD6Pqs1vFtJskc0CoIIgDTCCBBIwggL6oAMCAQICDwDB
'' SIG '' AIs8PIgR0T72Y+zfQDANBgkqhkiG9w0BAQQFADBwMSsw
'' SIG '' KQYDVQQLEyJDb3B5cmlnaHQgKGMpIDE5OTcgTWljcm9z
'' SIG '' b2Z0IENvcnAuMR4wHAYDVQQLExVNaWNyb3NvZnQgQ29y
'' SIG '' cG9yYXRpb24xITAfBgNVBAMTGE1pY3Jvc29mdCBSb290
'' SIG '' IEF1dGhvcml0eTAeFw05NzAxMTAwNzAwMDBaFw0yMDEy
'' SIG '' MzEwNzAwMDBaMHAxKzApBgNVBAsTIkNvcHlyaWdodCAo
'' SIG '' YykgMTk5NyBNaWNyb3NvZnQgQ29ycC4xHjAcBgNVBAsT
'' SIG '' FU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEhMB8GA1UEAxMY
'' SIG '' TWljcm9zb2Z0IFJvb3QgQXV0aG9yaXR5MIIBIjANBgkq
'' SIG '' hkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqQK9wXDmO/JO
'' SIG '' Gyifl3heMOqiqY0lX/j+lUyjt/6doiA+fFGim6KPYDJr
'' SIG '' 0UJkee6sdslU2vLrnIYcj5+EZrPFa3piI9YdPN4PAZLo
'' SIG '' lsS/LWaammgmmdA6LL8MtVgmwUbnCj44liypKDmo7EmD
'' SIG '' QuOED7uabFVhrIJ8oWAtd0zpmbRkO5pQHDEIJBSfqeeR
'' SIG '' KxjmPZhjFGBYBWWfHTdSh/en75QCxhvTv1VFs4mAvzrs
'' SIG '' VJROrv2nem10Tq8YzJYJKCEAV5BgaTe7SxIHPFb/W/uk
'' SIG '' ZgoIptKBVlfvtjteFoF3BNr2vq6Alf6wzX/WpxpyXDzK
'' SIG '' vPAIoyIwswaFybMgdxOF3wIDAQABo4GoMIGlMIGiBgNV
'' SIG '' HQEEgZowgZeAEFvQcO9pcp4jUX4Usk2O/8uhcjBwMSsw
'' SIG '' KQYDVQQLEyJDb3B5cmlnaHQgKGMpIDE5OTcgTWljcm9z
'' SIG '' b2Z0IENvcnAuMR4wHAYDVQQLExVNaWNyb3NvZnQgQ29y
'' SIG '' cG9yYXRpb24xITAfBgNVBAMTGE1pY3Jvc29mdCBSb290
'' SIG '' IEF1dGhvcml0eYIPAMEAizw8iBHRPvZj7N9AMA0GCSqG
'' SIG '' SIb3DQEBBAUAA4IBAQCV6AvAjfOXGDXtuAEk2HcR81xg
'' SIG '' Mp+eC8s+BZGIj8k65iHy8FeTLLWgR8hi7/zXzDs7Wqk2
'' SIG '' VGn+JG0/ycyq3gV83TGNPZ8QcGq7/hJPGGnA/NBD4xFa
'' SIG '' IE/qYnuvqhnIKzclLb5loRKKJQ9jo/dUHPkhydYV81Ks
'' SIG '' bkMyB/2CF/jlZ2wNUfa98VLHvefEMPwgMQmIHZUpGk3V
'' SIG '' HQKl8YDgA7Rb9LHdyFfuZUnHUlS2tAMoEv+Q1vAIj364
'' SIG '' l8WrNyzkeuSod+N2oADQaj/B0jaK4EESqDVqG2rbNeHU
'' SIG '' HATkqEUEyFozOG5NHA1itwqijNPVVD9GzRxVpnDbEjqH
'' SIG '' k3Wfp9KgMIIEEjCCAvqgAwIBAgIPAMEAizw8iBHRPvZj
'' SIG '' 7N9AMA0GCSqGSIb3DQEBBAUAMHAxKzApBgNVBAsTIkNv
'' SIG '' cHlyaWdodCAoYykgMTk5NyBNaWNyb3NvZnQgQ29ycC4x
'' SIG '' HjAcBgNVBAsTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEh
'' SIG '' MB8GA1UEAxMYTWljcm9zb2Z0IFJvb3QgQXV0aG9yaXR5
'' SIG '' MB4XDTk3MDExMDA3MDAwMFoXDTIwMTIzMTA3MDAwMFow
'' SIG '' cDErMCkGA1UECxMiQ29weXJpZ2h0IChjKSAxOTk3IE1p
'' SIG '' Y3Jvc29mdCBDb3JwLjEeMBwGA1UECxMVTWljcm9zb2Z0
'' SIG '' IENvcnBvcmF0aW9uMSEwHwYDVQQDExhNaWNyb3NvZnQg
'' SIG '' Um9vdCBBdXRob3JpdHkwggEiMA0GCSqGSIb3DQEBAQUA
'' SIG '' A4IBDwAwggEKAoIBAQCpAr3BcOY78k4bKJ+XeF4w6qKp
'' SIG '' jSVf+P6VTKO3/p2iID58UaKboo9gMmvRQmR57qx2yVTa
'' SIG '' 8uuchhyPn4Rms8VremIj1h083g8BkuiWxL8tZpqaaCaZ
'' SIG '' 0Dosvwy1WCbBRucKPjiWLKkoOajsSYNC44QPu5psVWGs
'' SIG '' gnyhYC13TOmZtGQ7mlAcMQgkFJ+p55ErGOY9mGMUYFgF
'' SIG '' ZZ8dN1KH96fvlALGG9O/VUWziYC/OuxUlE6u/ad6bXRO
'' SIG '' rxjMlgkoIQBXkGBpN7tLEgc8Vv9b+6RmCgim0oFWV++2
'' SIG '' O14WgXcE2va+roCV/rDNf9anGnJcPMq88AijIjCzBoXJ
'' SIG '' syB3E4XfAgMBAAGjgagwgaUwgaIGA1UdAQSBmjCBl4AQ
'' SIG '' W9Bw72lyniNRfhSyTY7/y6FyMHAxKzApBgNVBAsTIkNv
'' SIG '' cHlyaWdodCAoYykgMTk5NyBNaWNyb3NvZnQgQ29ycC4x
'' SIG '' HjAcBgNVBAsTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEh
'' SIG '' MB8GA1UEAxMYTWljcm9zb2Z0IFJvb3QgQXV0aG9yaXR5
'' SIG '' gg8AwQCLPDyIEdE+9mPs30AwDQYJKoZIhvcNAQEEBQAD
'' SIG '' ggEBAJXoC8CN85cYNe24ASTYdxHzXGAyn54Lyz4FkYiP
'' SIG '' yTrmIfLwV5MstaBHyGLv/NfMOztaqTZUaf4kbT/JzKre
'' SIG '' BXzdMY09nxBwarv+Ek8YacD80EPjEVogT+pie6+qGcgr
'' SIG '' NyUtvmWhEoolD2Oj91Qc+SHJ1hXzUqxuQzIH/YIX+OVn
'' SIG '' bA1R9r3xUse958Qw/CAxCYgdlSkaTdUdAqXxgOADtFv0
'' SIG '' sd3IV+5lScdSVLa0AygS/5DW8AiPfriXxas3LOR65Kh3
'' SIG '' 43agANBqP8HSNorgQRKoNWobats14dQcBOSoRQTIWjM4
'' SIG '' bk0cDWK3CqKM09VUP0bNHFWmcNsSOoeTdZ+n0qAwggSd
'' SIG '' MIIDhaADAgECAgphR1K6AAAAAAAEMA0GCSqGSIb3DQEB
'' SIG '' BQUAMHkxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNo
'' SIG '' aW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQK
'' SIG '' ExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xIzAhBgNVBAMT
'' SIG '' Gk1pY3Jvc29mdCBUaW1lc3RhbXBpbmcgUENBMB4XDTA2
'' SIG '' MDkxNjAxNTMwMFoXDTExMDkxNjAyMDMwMFowgaYxCzAJ
'' SIG '' BgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAw
'' SIG '' DgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3Nv
'' SIG '' ZnQgQ29ycG9yYXRpb24xJzAlBgNVBAsTHm5DaXBoZXIg
'' SIG '' RFNFIEVTTjpEOEE5LUNGQ0MtNTc5QzEnMCUGA1UEAxMe
'' SIG '' TWljcm9zb2Z0IFRpbWVzdGFtcGluZyBTZXJ2aWNlMIIB
'' SIG '' IjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAm23c
'' SIG '' hlHoMjs3OpYlss9v7mG1QdIYO1qdeGe6+B/ZCFWSiH7j
'' SIG '' QVP67ChU/rXa/nA7lSdIfkOgMi8mgUryAnZ3yMmp+KIh
'' SIG '' WH4NvQHaJMb+RBEFNToBqOpUCjMsh9J+QbPoCdmwvuOZ
'' SIG '' Jaa8Je3X047b9LdtG0kL5tPDh27uRsl/823r54MeqFNG
'' SIG '' P8okfuZ8ySz7eRQoRcBPNmtTGqeGs+f84cGfUQnbvKW7
'' SIG '' /sqHCfa3Mhm+4UpRvLx8rCyVapdz6nJXoZyLhtibvUv8
'' SIG '' JzPBbTKs4GgY2G46LiJD0fmP7fEAAQ1kwMmj3Q/xyOlU
'' SIG '' yhH/3HgpPh2sWMDb36rcrmUb0528ZwIDAQABo4H4MIH1
'' SIG '' MB0GA1UdDgQWBBRPGImK0soAeMbsWQ0P/XzEwSKA3jAf
'' SIG '' BgNVHSMEGDAWgBRv6E4/l7k0q0uGj7yc6qw7QUPG0DBE
'' SIG '' BgNVHR8EPTA7MDmgN6A1hjNodHRwOi8vY3JsLm1pY3Jv
'' SIG '' c29mdC5jb20vcGtpL2NybC9wcm9kdWN0cy90c3BjYS5j
'' SIG '' cmwwSAYIKwYBBQUHAQEEPDA6MDgGCCsGAQUFBzAChixo
'' SIG '' dHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpL2NlcnRz
'' SIG '' L3RzcGNhLmNydDATBgNVHSUEDDAKBggrBgEFBQcDCDAO
'' SIG '' BgNVHQ8BAf8EBAMCBsAwDQYJKoZIhvcNAQEFBQADggEB
'' SIG '' ADcnHvWMQOD2ZSY+ZMSQvD7jV4XdQw1AhGe+h6gq2ty0
'' SIG '' NiCYjjN8Ll/gUHthMfMaE96EveppHFh8sxuT4QgngUW2
'' SIG '' 1HDKFLdfulfp1F7QO0Oqtz+22mGLcc/UfdV7br+0ylow
'' SIG '' kd/aCg6jNZ8lYU7AMnQregaUcgCsGJ1L5Z4rxTpUrKRg
'' SIG '' 2Kf3m3/ZqW3tRGu63OAS+vCthwyVYwoyHolOzMx+pzel
'' SIG '' /l/YZ/pGS9FtHad90r4C//NugvOHdMRp5blwzEtlowc1
'' SIG '' qUSehH05bv4UBb0aUCG1Pp/zdxyPwpqdV+FpfWnog88C
'' SIG '' byoiuzczOnL61jAdka32UBrrE946xbdczbMwggSdMIID
'' SIG '' haADAgECAgphSXztAAAAAAAFMA0GCSqGSIb3DQEBBQUA
'' SIG '' MHkxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5n
'' SIG '' dG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVN
'' SIG '' aWNyb3NvZnQgQ29ycG9yYXRpb24xIzAhBgNVBAMTGk1p
'' SIG '' Y3Jvc29mdCBUaW1lc3RhbXBpbmcgUENBMB4XDTA2MDkx
'' SIG '' NjAxNTUyMloXDTExMDkxNjAyMDUyMlowgaYxCzAJBgNV
'' SIG '' BAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYD
'' SIG '' VQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQg
'' SIG '' Q29ycG9yYXRpb24xJzAlBgNVBAsTHm5DaXBoZXIgRFNF
'' SIG '' IEVTTjoxMEQ4LTU4NDctQ0JGODEnMCUGA1UEAxMeTWlj
'' SIG '' cm9zb2Z0IFRpbWVzdGFtcGluZyBTZXJ2aWNlMIIBIjAN
'' SIG '' BgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA6roFY8jZ
'' SIG '' ea6ERD6ls8TtTJ4k3zl2HgnWMkpYeNIr2aUHkO/nPfu9
'' SIG '' Jnyj++V9fjLP2T2LOTfy+Ng7NBbUkoL7NOxohXIaj+C4
'' SIG '' TOC4hfMzCgLBonZzNUxd8bfhSn0duJR42/8ehRVCRnHO
'' SIG '' fydXEtGDTzvP+t72i+0/AOPV3mH5F41LpIE89WlA6uGJ
'' SIG '' vwdPunR76QzlR+qrbPHVZ4EI+BbKfRO7c+IJTPpi++2g
'' SIG '' OZo6/usRyGEeYljYClSD1TtLS+JVvS9gGo6SBUPaXeuC
'' SIG '' CiOXCaAFMWWLk04eQSGikpD9RURFbzWxRTetaall+TRD
'' SIG '' sRfCOznhEIzyGofjVFAfO50xrQIDAQABo4H4MIH1MB0G
'' SIG '' A1UdDgQWBBR+cvAuP1Yp4CX3aLgB/Evhfs/jPjAfBgNV
'' SIG '' HSMEGDAWgBRv6E4/l7k0q0uGj7yc6qw7QUPG0DBEBgNV
'' SIG '' HR8EPTA7MDmgN6A1hjNodHRwOi8vY3JsLm1pY3Jvc29m
'' SIG '' dC5jb20vcGtpL2NybC9wcm9kdWN0cy90c3BjYS5jcmww
'' SIG '' SAYIKwYBBQUHAQEEPDA6MDgGCCsGAQUFBzAChixodHRw
'' SIG '' Oi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpL2NlcnRzL3Rz
'' SIG '' cGNhLmNydDATBgNVHSUEDDAKBggrBgEFBQcDCDAOBgNV
'' SIG '' HQ8BAf8EBAMCBsAwDQYJKoZIhvcNAQEFBQADggEBAGl6
'' SIG '' ggkMFtHez0aJLr/RNHqBfycoQSrz0yGSDpetX1NeKfnt
'' SIG '' wVRKqH33E9ALFPlN8oYVAG7jgx0oRacsOTLdb5o3Wu4j
'' SIG '' Uo9UA40/p5xkOPY2yBRDtjo+mMkNw3GBKPNmpzHiXF2P
'' SIG '' +VJS4Vzrk5CdaQlMidHRdkw0DWrhfESnK1uDVH9FJBkl
'' SIG '' xIpGxSXjGYBpKRT2F8bwIiyBRl4r9Pmmxnc+I2/5pmSF
'' SIG '' jqJiDaktHqjlkD5//7CO/Jfs8f0Er81Jzlp0rPrzEx8b
'' SIG '' Oc6jtNa89LTuyK3yVh77PPHI1ipEvL+cP31mGM2yIGMK
'' SIG '' ykA9ZTIZfLK4PcEmSE4iGZlujDDB8ZEwggSdMIIDhaAD
'' SIG '' AgECAhBqC5lPwAAlqxHbRR9YemeiMA0GCSqGSIb3DQEB
'' SIG '' BQUAMHAxKzApBgNVBAsTIkNvcHlyaWdodCAoYykgMTk5
'' SIG '' NyBNaWNyb3NvZnQgQ29ycC4xHjAcBgNVBAsTFU1pY3Jv
'' SIG '' c29mdCBDb3Jwb3JhdGlvbjEhMB8GA1UEAxMYTWljcm9z
'' SIG '' b2Z0IFJvb3QgQXV0aG9yaXR5MB4XDTA2MDkxNjAxMDQ0
'' SIG '' N1oXDTE5MDkxNTA3MDAwMFoweTELMAkGA1UEBhMCVVMx
'' SIG '' EzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1Jl
'' SIG '' ZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3Jh
'' SIG '' dGlvbjEjMCEGA1UEAxMaTWljcm9zb2Z0IFRpbWVzdGFt
'' SIG '' cGluZyBQQ0EwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw
'' SIG '' ggEKAoIBAQDcN277r8hCSnEYyM5IPlPA+qsUuiwyuxJP
'' SIG '' UsiD7T4z2Ukxkii2kWTgH1CEusJL0X8F+O91vovHqNWu
'' SIG '' aXBmeCdm6La374W5ze6q/RKkC1kiKS/PQNlWBBt2tW1k
'' SIG '' bUpU293x3r+fg8eA339MAjeU9cCeCFYeaEfN2cB2XC99
'' SIG '' tiUEtFZbahxj/4B8PO7VBCVNOXd0B13CXNiGNyx1yQ7q
'' SIG '' HjkJfHb+nWxueuDsPo+XnnEOXypPGGJgMp7Sg04rIlxo
'' SIG '' RYveL4QQULL5tRqNbO4lmxP4yxDXhQ70gnZzNsaVeqLM
'' SIG '' YAbsBbCGM7f4lFuEQYRYhZRusB8sSMxvnEPgauh/Jo5r
'' SIG '' AgMBAAGjggEoMIIBJDATBgNVHSUEDDAKBggrBgEFBQcD
'' SIG '' CDCBogYDVR0BBIGaMIGXgBBb0HDvaXKeI1F+FLJNjv/L
'' SIG '' oXIwcDErMCkGA1UECxMiQ29weXJpZ2h0IChjKSAxOTk3
'' SIG '' IE1pY3Jvc29mdCBDb3JwLjEeMBwGA1UECxMVTWljcm9z
'' SIG '' b2Z0IENvcnBvcmF0aW9uMSEwHwYDVQQDExhNaWNyb3Nv
'' SIG '' ZnQgUm9vdCBBdXRob3JpdHmCDwDBAIs8PIgR0T72Y+zf
'' SIG '' QDAQBgkrBgEEAYI3FQEEAwIBADAdBgNVHQ4EFgQUb+hO
'' SIG '' P5e5NKtLho+8nOqsO0FDxtAwGQYJKwYBBAGCNxQCBAwe
'' SIG '' CgBTAHUAYgBDAEEwCwYDVR0PBAQDAgGGMA8GA1UdEwEB
'' SIG '' /wQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAJRNETHC
'' SIG '' fFC7EY6hYQcBDoxwRY3vc1S9PwkFLf+4UVOFHO05kbej
'' SIG '' VgvejLY7G9H7rKfJt7FRIRtvCGl+awOiIkbtbLRtfCK4
'' SIG '' RtOE840PvgeKNsHrfulwXUWfktLMzt2OwOG/Ks187Mmu
'' SIG '' MtWHuctjxDbRGCG/dt47mrMbc54hiNi0tBJUjPScwmVK
'' SIG '' migmnGCKDzvHE2V4SLvPrYM6T7BiWN4w6ek5HeOJ8to5
'' SIG '' gfkTIYxkgGMGBJbymgJDL3tGiLr/Atll+Ure2gN0k7MF
'' SIG '' bgzMndwoYXxI8RecESE4AhyHrAbFljK45UDGUz29qYne
'' SIG '' 6GY3jfQilpzMsHdUUTrWckSyI/YwggTDMIIDr6ADAgEC
'' SIG '' AhBqC5lPwAAdqxHaxAKhZie6MAkGBSsOAwIdBQAwcDEr
'' SIG '' MCkGA1UECxMiQ29weXJpZ2h0IChjKSAxOTk3IE1pY3Jv
'' SIG '' c29mdCBDb3JwLjEeMBwGA1UECxMVTWljcm9zb2Z0IENv
'' SIG '' cnBvcmF0aW9uMSEwHwYDVQQDExhNaWNyb3NvZnQgUm9v
'' SIG '' dCBBdXRob3JpdHkwHhcNMDYwNDA0MTc0NDE0WhcNMTIw
'' SIG '' NDI2MDcwMDAwWjCBpjELMAkGA1UEBhMCVVMxEzARBgNV
'' SIG '' BAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
'' SIG '' HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEr
'' SIG '' MCkGA1UECxMiQ29weXJpZ2h0IChjKSAyMDAwIE1pY3Jv
'' SIG '' c29mdCBDb3JwLjEjMCEGA1UEAxMaTWljcm9zb2Z0IENv
'' SIG '' ZGUgU2lnbmluZyBQQ0EwggEgMA0GCSqGSIb3DQEBAQUA
'' SIG '' A4IBDQAwggEIAoIBAQDDzCCNvN//PlDuesLUJCX2ds4h
'' SIG '' /80qVk7KnLeCsjV5LQDEqAjVY8m3pfbpwcHWsYyWogf6
'' SIG '' D7aCUprrgsa9EMWowO5rhI5TG7tQ+mQBicEW1IJoAEB4
'' SIG '' RPUSOE77Y1Hg+j255Tex32MHIztxQDRH9GuuRvUncx4i
'' SIG '' y0IZHlG2UprTo9ATxhk/cQZt8pUhRF9C7cDJmWQguME0
'' SIG '' /KJE5nuyHS+4pt70od+bIQ/+WDFBVTh+r1jn5OxZeSWr
'' SIG '' 9yovET84eD5Cf6do5H4iaBfmSpLEeERSR6FPhImTm8Bn
'' SIG '' e+oJ+4YDffaZcTwrp2aYzN8t4isCGg80SGX1PBKv8Ycc
'' SIG '' HSZSb8wDAgEDo4IBKjCCASYwEwYDVR0lBAwwCgYIKwYB
'' SIG '' BQUHAwMwgaIGA1UdAQSBmjCBl4AQW9Bw72lyniNRfhSy
'' SIG '' TY7/y6FyMHAxKzApBgNVBAsTIkNvcHlyaWdodCAoYykg
'' SIG '' MTk5NyBNaWNyb3NvZnQgQ29ycC4xHjAcBgNVBAsTFU1p
'' SIG '' Y3Jvc29mdCBDb3Jwb3JhdGlvbjEhMB8GA1UEAxMYTWlj
'' SIG '' cm9zb2Z0IFJvb3QgQXV0aG9yaXR5gg8AwQCLPDyIEdE+
'' SIG '' 9mPs30AwEgYJKwYBBAGCNxUBBAUCAwMABDAdBgNVHQ4E
'' SIG '' FgQUJfgrS13IclSt5fagKhcW+8H5U4EwGQYJKwYBBAGC
'' SIG '' NxQCBAweCgBTAHUAYgBDAEEwCwYDVR0PBAQDAgFGMA8G
'' SIG '' A1UdEwEB/wQFMAMBAf8wCQYFKw4DAh0FAAOCAQEAY+Pg
'' SIG '' 8wW4sOoLCzTRgjE+iWJF1Qin+WFlyC4D+jhIQc+18ieD
'' SIG '' 0+PFVlOotRnOzObxoPlWtkiURyTlqR/cetT2FnoS2/OQ
'' SIG '' G+wIXbOFkLmMWLsczJXTlZQz9JHe/4ibXktJUDkmOiAb
'' SIG '' VDf8fVwVk8PcHI7wYVI85QftZu957I/OV2NllRhJoHrf
'' SIG '' ZbffJq7+yBK2xqLMxl+LcPPK26uCbgfcZRm5qPaGwglC
'' SIG '' mPEmrGl6scErp7BmH6WvhwhrlxO4sDaZHgWjEzijwKww
'' SIG '' Proh1zCmymISHK9XjeXxehG6XjwMN/GTwZKITgRaBVzH
'' SIG '' z9ap2eF9kXgn+7RupY8GM1ixXioRDzCCBTMwggQboAMC
'' SIG '' AQICCmFGnssABAAAAGUwDQYJKoZIhvcNAQEFBQAwgaYx
'' SIG '' CzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9u
'' SIG '' MRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
'' SIG '' b3NvZnQgQ29ycG9yYXRpb24xKzApBgNVBAsTIkNvcHly
'' SIG '' aWdodCAoYykgMjAwMCBNaWNyb3NvZnQgQ29ycC4xIzAh
'' SIG '' BgNVBAMTGk1pY3Jvc29mdCBDb2RlIFNpZ25pbmcgUENB
'' SIG '' MB4XDTA2MDQwNDE5NDM0NloXDTA3MTAwNDE5NTM0Nlow
'' SIG '' dDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0
'' SIG '' b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1p
'' SIG '' Y3Jvc29mdCBDb3Jwb3JhdGlvbjEeMBwGA1UEAxMVTWlj
'' SIG '' cm9zb2Z0IENvcnBvcmF0aW9uMIIBIjANBgkqhkiG9w0B
'' SIG '' AQEFAAOCAQ8AMIIBCgKCAQEAzYGWOK5covLB397Qq5WN
'' SIG '' 1jydH4vDXYYuXfCxcvWrrIhqtdqxInsLyMilS5FeIhPp
'' SIG '' +fUjnbX0bnau7+6kPMfEwFlcP6uzczMmpmKBYXmhYvRu
'' SIG '' iJXQbt3Hn9KkURF2YbpwimWhlhaJp12B0ERm5dtWnkDK
'' SIG '' /Nx2JC5EMADl1n17lRHVWB2j6E8LyYjcotZTmWzKY8qZ
'' SIG '' apqSXkxNEegv01tbXl9So3MtpbuERQ2MGRV2ywjamqZw
'' SIG '' FehN7Gn9XbJrj+0pUTc4i8ZGSRWUUJiw9Gik194JcWd0
'' SIG '' nneMHYVrl+rnX0XM4OZxDdFjAJN7MZiOC7QTvbPQ7vHf
'' SIG '' Ie6pYGHuN0M9wwIDAQABo4IBkjCCAY4wDgYDVR0PAQH/
'' SIG '' BAQDAgbAMB0GA1UdDgQWBBTu2WupdVPNT+4bThkGHqOc
'' SIG '' q8+U/TATBgNVHSUEDDAKBggrBgEFBQcDAzCBqQYDVR0j
'' SIG '' BIGhMIGegBQl+CtLXchyVK3l9qAqFxb7wflTgaF0pHIw
'' SIG '' cDErMCkGA1UECxMiQ29weXJpZ2h0IChjKSAxOTk3IE1p
'' SIG '' Y3Jvc29mdCBDb3JwLjEeMBwGA1UECxMVTWljcm9zb2Z0
'' SIG '' IENvcnBvcmF0aW9uMSEwHwYDVQQDExhNaWNyb3NvZnQg
'' SIG '' Um9vdCBBdXRob3JpdHmCEGoLmU/AAB2rEdrEAqFmJ7ow
'' SIG '' SwYDVR0fBEQwQjBAoD6gPIY6aHR0cDovL2NybC5taWNy
'' SIG '' b3NvZnQuY29tL3BraS9jcmwvcHJvZHVjdHMvQ29kZVNp
'' SIG '' Z25QQ0EyLmNybDBPBggrBgEFBQcBAQRDMEEwPwYIKwYB
'' SIG '' BQUHMAKGM2h0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9w
'' SIG '' a2kvY2VydHMvQ29kZVNpZ25QQ0EyLmNydDANBgkqhkiG
'' SIG '' 9w0BAQUFAAOCAQEAONnvlTibXJgUXVRuad8CyOez+9PC
'' SIG '' Ta0vq39UDdoytvhq5g37IRp3PqVoerSVfopc8kPEg5tl
'' SIG '' fYhQUXyCFPWDc9eivlzKAnDOJmwXvFIUpYnAt+ShzKF1
'' SIG '' nZFxPRvAVgBWtfiEJtpeM/vWJXpemtqm+/TyQRqsVUat
'' SIG '' SNyROBNYCUnx8zGHH7wEjlsSZQPpC1HQoQyKmb3ZwajQ
'' SIG '' CBUlIbW2V4kc0VuGNaXK/aqH7Kk3P7dDa+Mg8UW8fq7p
'' SIG '' 8VWyoUi8Zb5TNNnJ6AZjBAZ4blD/SLub6kNah9utCoD1
'' SIG '' WcUs5OV/W0rlMnnuIoWSDC2zUFvGwkBYWKvSzeMvwc3s
'' SIG '' bZ83eTGCBMcwggTDAgEBMIG1MIGmMQswCQYDVQQGEwJV
'' SIG '' UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
'' SIG '' UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
'' SIG '' cmF0aW9uMSswKQYDVQQLEyJDb3B5cmlnaHQgKGMpIDIw
'' SIG '' MDAgTWljcm9zb2Z0IENvcnAuMSMwIQYDVQQDExpNaWNy
'' SIG '' b3NvZnQgQ29kZSBTaWduaW5nIFBDQQIKYUaeywAEAAAA
'' SIG '' ZTAJBgUrDgMCGgUAoIHEMBkGCSqGSIb3DQEJAzEMBgor
'' SIG '' BgEEAYI3AgEEMBwGCisGAQQBgjcCAQsxDjAMBgorBgEE
'' SIG '' AYI3AgEVMCMGCSqGSIb3DQEJBDEWBBRmTMSPjVPI5QIo
'' SIG '' o+2my/VnZXzbYjBkBgorBgEEAYI3AgEMMVYwVKAsgCoA
'' SIG '' TQBpAGMAcgBvAHMAbwBmAHQAIABDAG8AcgBwAG8AcgBh
'' SIG '' AHQAaQBvAG6hJIAiaHR0cDovL3d3dy5taWNyb3NvZnQu
'' SIG '' Y29tL2xlYXJuaW5nIDANBgkqhkiG9w0BAQEFAASCAQBp
'' SIG '' 7fRwZJw2FjKgOqxt0atSh712ksJV6HUm8Jw60BUHuuji
'' SIG '' lemiXfXRR9ZEyTBKh9oij1cIxdldA4NMDPhARe1U1o/D
'' SIG '' saFY8Og8F3s+8iJfbaZkL6Om3M6L88ItYir4z+ymbeTG
'' SIG '' ZShFAMpCRIPltJecnyuoDi1CQg5spQaEkLhwBhP80Xvp
'' SIG '' TurSFY8xnjaHby+o1hE4FtjNjH6J4YmEYHWFVYs2XSN2
'' SIG '' yzX429BNhbXk3vlhI637u/BZBWDXc0rYMshy2tUqPlTe
'' SIG '' 3olrLEdoWSmT2Ik7xP/F0pOuwqqdH54KSFYOBZ/wnlSq
'' SIG '' NW259+5i7Neo3eRVjIDrKxyu4kmEQxGYoYICHzCCAhsG
'' SIG '' CSqGSIb3DQEJBjGCAgwwggIIAgEBMIGHMHkxCzAJBgNV
'' SIG '' BAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYD
'' SIG '' VQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQg
'' SIG '' Q29ycG9yYXRpb24xIzAhBgNVBAMTGk1pY3Jvc29mdCBU
'' SIG '' aW1lc3RhbXBpbmcgUENBAgphSXztAAAAAAAFMAcGBSsO
'' SIG '' AwIaoF0wGAYJKoZIhvcNAQkDMQsGCSqGSIb3DQEHATAc
'' SIG '' BgkqhkiG9w0BCQUxDxcNMDcwMjIyMjE1MTMxWjAjBgkq
'' SIG '' hkiG9w0BCQQxFgQUq9SwIHNqNKA4OZQM17yoBocHK9Qw
'' SIG '' DQYJKoZIhvcNAQEFBQAEggEAtWVFjEfdcC2Y86LbPOnQ
'' SIG '' t/raB/DaiUrHS0vSvJDqMRypS4zPQ2GkRkcC8A8clCyr
'' SIG '' bXTzDighvUMB0C6BE55tsjT2nf/SBmA+Yv3uBPxZ581f
'' SIG '' ODTBrlAYTGsl900/GNiLfhmIbmrKtmDj0Wv5AusSf5F2
'' SIG '' +tmt1+HUVHAfY0XvTlIZvSiQytPhsQwKiEyrwtz9vD3R
'' SIG '' l7Raa9pY+NIhb0ri+UgDkFGbbyuFG2RyqNhjZkWpu/kE
'' SIG '' 7+nrpL8p52V+ZI8RHX8PpaVpYYjoMiSstXNWB/xcmd5M
'' SIG '' lG7KbC089ZimXXvAWYmAPuDzoW11DWFf1JPRs9jFdbny
'' SIG '' Q1wsuERMj6CDig==
'' SIG '' End signature block
